﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;
using System.Windows.Forms.DataVisualization.Charting;
using HeuristicLab.Analysis.Views;

namespace HeuristicLab.Analysis.Statistics {
  public class DensityDataTableView : DataTableView {

    protected override void CalculateHistogram(Series series, DataRow row) {
      base.CalculateHistogram(series, row);

      string densitySeriesName = "Density " + row.Name;
      double stepWidth = series.Points[1].XValue - series.Points[0].XValue;

      if (chart.Series.Any(x => x.Name == densitySeriesName)) {
        var ds = chart.Series.Single(x => x.Name == densitySeriesName);
        chart.Series.Remove(ds);
      }

      var res = NormalDistribution.Density(row.Values.ToArray(), row.Values.Count, stepWidth);

      Series newSeries = new Series(densitySeriesName);
      newSeries.Color = series.Color;
      newSeries.ChartType = SeriesChartType.FastLine;
      foreach (var r in res) {
        newSeries.Points.Add(new DataPoint(r.Item1, r.Item2));
      }

      chart.Series.Add(newSeries);
    }
  }
}
